<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output method="html" indent="yes" />
  <xsl:param name="bodyOnly">0</xsl:param>
  <xsl:param name="showTV">1</xsl:param>
  <xsl:param name="showRadio">1</xsl:param>
  <xsl:param name="showFavoritesTV">1</xsl:param>
  <xsl:param name="showFavoritesRadio">1</xsl:param>

  <!-- ========================= -->
  <!-- root element: Project     -->
  <!-- ========================= -->
  <xsl:template match="Project">
    <xsl:call-template name="showProject">
      <xsl:with-param name="Project" select="/Project" />
    </xsl:call-template>
  </xsl:template>

  <!-- ========================= -->
  <!-- Show Document template    -->
  <!-- ========================= -->
  <xsl:template name="showProject">
    <xsl:param name="Project" />

    <xsl:if test="bodyOnly != 1">
      <xsl:text disable-output-escaping="yes">
        &lt;HTML&gt;
      </xsl:text>
      <head>
        <title>Project - <xsl:value-of select="$Project/Version" /></title>
      </head>
      <xsl:text disable-output-escaping="yes">
          &lt;BODY&gt;
      </xsl:text>
    </xsl:if>

        <table width='100%' border='0' cellSpacing='0' cellPadding='4'>
          <tr>
            <td bgColor='#f0f0f0' align='center'>
              <font size='+1' color='blue'><b>Channel Lineup</b></font>
            </td>
          </tr>
        </table>
        
      <xsl:if test="$showTV != 0">
        <BR/>
        <table width='100%' border='1' borderColor='black' cellSpacing='0'>
          <tr bgColor='#ffffb0'>
            <td colSpan='5' align='center'><font  color='#0000ff'>
            <B>TV Channels</B>
            (<xsl:value-of select="count(Satellites/Satellite/Transponders/Transponder/Channels/Channel[Name!='' and ChannelType='TV'])"/>)
            </font></td>
          </tr>
          <tr bgColor='#ffffb0'>
            <td>No.</td>
            <td>Sat</td>
            <td>Channel</td>
            <td>Station ID</td>
            <td>Name</td>
          </tr>
          <xsl:apply-templates select="Satellites/Satellite/Transponders/Transponder/Channels/Channel[Name!='' and ChannelType='TV']">
            <xsl:sort select="ChannelNo" data-type="number"/>
            <!--xsl:sort select="Name" data-type="text"/-->
            <!--xsl:with-param name="Documents" select="$Documents"/-->
          </xsl:apply-templates>
        </table>
      </xsl:if>

      <xsl:if test="$showRadio != 0">
        <BR/>
        <table width='100%' border='1' borderColor='black' cellSpacing='0'>
          <tr bgColor='#ffffb0'>
            <td colSpan='5' align='center'><font  color='#0000ff'>
            <B>RADIO Channels</B>
            (<xsl:value-of select="count(Satellites/Satellite/Transponders/Transponder/Channels/Channel[Name!='' and ChannelType='RADIO'])"/>)
            </font></td>
          </tr>
          <tr bgColor='#ffffb0'>
            <td>No.</td>
            <td>Sat</td>
            <td>Channel</td>
            <td>Station ID</td>
            <td>Name</td>
          </tr>
          <xsl:apply-templates select="Satellites/Satellite/Transponders/Transponder/Channels/Channel[Name!='' and ChannelType='RADIO']">
            <xsl:sort select="ChannelNo" data-type="number"/>
            <!--xsl:sort select="Name" data-type="text"/-->
            <!--xsl:with-param name="Documents" select="$Documents"/-->
          </xsl:apply-templates>
        </table>
      </xsl:if>

      <xsl:if test="$showFavoritesTV != 0">
        <table width='100%' border='0' borderColor='black' cellSpacing='0'>
          <xsl:apply-templates select="Favorites/Favorite[Name!='']">
            <xsl:sort select="Id" data-type="number"/>
            <xsl:with-param name="ChannelType" select="'TV'"/>
          </xsl:apply-templates>
        </table>
      </xsl:if>

      <xsl:if test="$showFavoritesRadio != 0">
        <table width='100%' border='0' borderColor='black' cellSpacing='0'>
          <xsl:apply-templates select="Favorites/Favorite[Name!='']">
            <xsl:sort select="Id" data-type="number"/>
            <xsl:with-param name="ChannelType" select="'RADIO'"/>
          </xsl:apply-templates>
        </table>
      </xsl:if>

    <xsl:if test="bodyOnly != 1">
      <xsl:text disable-output-escaping="yes">
          &lt;BODY&gt;
        &lt;HTML&gt;
      </xsl:text>
    </xsl:if>
  </xsl:template>

  <!-- ========================= -->
  <!-- Favorite Template: item    -->
  <!-- ========================= -->
  <xsl:template match="Favorite">
  <xsl:param name="ChannelType" select="'TV'"/>
  
  <xsl:variable name="FavoriteId" select="Id"/>
    <tr>
      <td>&#160;</td>
    </tr>
    <tr>
      <td>
        <table width='100%' border='1' borderColor='black' cellSpacing='0'>
          <tr bgColor='#ffffb0'>
            <td colSpan='5' align='center'>
              <font  color='#0000ff'>
                <B>
                  <xsl:value-of select="Name"/>
                  <xsl:choose>
                    <xsl:when test="$ChannelType = 'TV'"> - TV</xsl:when>
                    <xsl:otherwise> - Radio</xsl:otherwise>
                  </xsl:choose>
                </B>
              </font>
            </td>
          </tr>
          <tr bgColor='#ffffb0'>
            <td>No.</td>
            <td>Sat</td>
            <td>Channel</td>
            <td>Station ID</td>
            <td>Name</td>
          </tr>
          <xsl:apply-templates select="../../Satellites/Satellite/Transponders/Transponder/Channels/Channel[Name!='' and ChannelType=$ChannelType]/Favorites[Id=$FavoriteId]/..">
            <xsl:sort select="ChannelNo" data-type="number"/>
          </xsl:apply-templates>
        </table>
      </td>
    </tr>
  </xsl:template>

  <!-- ========================= -->
  <!-- Channel Template: item    -->
  <!-- ========================= -->
  <xsl:template match="Channel">
    <tr>
      <xsl:choose>
        <xsl:when test="ECMPID = 0">
          <xsl:attribute name="bgColor">#f4fff4</xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="bgColor">#fff0f0</xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      <td><xsl:value-of select="position()" /></td>
      <td><xsl:value-of select="../../../../Name"/></td>
      <td><xsl:value-of select="ChannelNo"/></td>
      <td><xsl:value-of select="SID"/></td>
      <td>
        <xsl:call-template name="showField">
          <xsl:with-param name="field" select="Name"/>
        </xsl:call-template>
      </td>
    </tr>
  </xsl:template>

  <!-- ========================= -->
  <!-- TEMPLATE: showField -->
  <!-- ========================= -->
  <xsl:template name="showField">
    <xsl:param name="field"/>

    <xsl:choose>
      <xsl:when test="string-length(substring-before($field, '_TRSP#@')) > 0">
        <xsl:value-of select="substring-before($field, '_TRSP#@')"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$field"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

</xsl:stylesheet>
