<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:msxsl="urn:schemas-microsoft-com:xslt">
  <xsl:output method="html" indent="yes" />
  <xsl:param name="bodyOnly">0</xsl:param>
  <xsl:param name="showTV">1</xsl:param>
  <xsl:param name="showRadio">1</xsl:param>
  <xsl:param name="showFavoritesTV">0</xsl:param>
  <xsl:param name="showFavoritesRadio">0</xsl:param>

  <xsl:param name="columnCount">4</xsl:param>
  <xsl:param name="rowsPerPage">40</xsl:param>

  <xsl:param name="fontSize">1</xsl:param>
  <xsl:param name="channelFreeBgColor">#f4fff4</xsl:param>
  <xsl:param name="channelScramblBgColor">#fff0f0</xsl:param>

  <!-- ========================= -->
  <!-- root element: Project     -->
  <!-- ========================= -->
  <xsl:template match="Project">
    <xsl:call-template name="showProject">
      <xsl:with-param name="Project" select="/Project" />
    </xsl:call-template>
  </xsl:template>

  <!-- ========================= -->
  <!-- Show Document template    -->
  <!-- ========================= -->
  <xsl:template name="showProject">
    <xsl:param name="Project" />

    <xsl:if test="bodyOnly != 1">
      <xsl:text disable-output-escaping="yes">
        &lt;HTML&gt;
      </xsl:text>
      <head>
        <title>Project - <xsl:value-of select="$Project/Version" /></title>
      </head>
      <xsl:text disable-output-escaping="yes">
          &lt;BODY&gt;
      </xsl:text>
    </xsl:if>

      <table width='100%' border='0' cellSpacing='0' cellPadding='4'>
        <tr>
          <td bgColor='#f0f0f0' align='center'>
            <font size='+1' color='blue'><b>Channel Lineup</b></font>
          </td>
        </tr>
      </table>
        
      <xsl:if test="$showTV != 0">
        <BR/>

        <xsl:variable name="channelNodes">
          <xsl:for-each select ="Satellites/Satellite/Transponders/Transponder/Channels/Channel[Name!='' and ChannelType='TV']" >
            <xsl:sort select="ChannelNo" data-type="number"/>
              <Channel>
                <ChannelNo><xsl:value-of select="position()"/></ChannelNo>
                <Name><xsl:value-of select="Name"/></Name>
              </Channel>
          </xsl:for-each>
        </xsl:variable>

        <xsl:call-template name="showChannels">
          <xsl:with-param name="title">TV Channels</xsl:with-param>
          <xsl:with-param name="channelNodes" select="msxsl:node-set($channelNodes)"/>
        </xsl:call-template>

      </xsl:if>

      <xsl:if test="$showRadio != 0">
        <BR/>

        <xsl:variable name="channelNodes">
          <xsl:for-each select ="Satellites/Satellite/Transponders/Transponder/Channels/Channel[Name!='' and ChannelType='RADIO']" >
            <xsl:sort select="ChannelNo" data-type="number"/>
            <Channel>
              <ChannelNo><xsl:value-of select="position()"/></ChannelNo>
              <Name><xsl:value-of select="Name"/></Name>
            </Channel>
          </xsl:for-each>
        </xsl:variable>

        <xsl:call-template name="showChannels">
          <xsl:with-param name="title">RADIO Channels</xsl:with-param>
          <xsl:with-param name="channelNodes" select="msxsl:node-set($channelNodes)"/>
        </xsl:call-template>

      </xsl:if>

      <xsl:if test="$showFavoritesTV != 0">
        <table width='100%' border='0' borderColor='black' cellSpacing='0'>
          <xsl:apply-templates select="Favorites/Favorite[Name!='']">
            <xsl:sort select="Id" data-type="number"/>
            <xsl:with-param name="ChannelType" select="'TV'"/>
          </xsl:apply-templates>
        </table>
      </xsl:if>

      <xsl:if test="$showFavoritesRadio != 0">
        <table width='100%' border='0' borderColor='black' cellSpacing='0'>
          <xsl:apply-templates select="Favorites/Favorite[Name!='']">
            <xsl:sort select="Id" data-type="number"/>
            <xsl:with-param name="ChannelType" select="'RADIO'"/>
          </xsl:apply-templates>
        </table>
      </xsl:if>

    <xsl:if test="bodyOnly != 1">
      <xsl:text disable-output-escaping="yes">
          &lt;BODY&gt;
        &lt;HTML&gt;
      </xsl:text>
    </xsl:if>
  </xsl:template>

  <!-- ========================= -->
  <!-- Favorite Template: item    -->
  <!-- ========================= -->
  <xsl:template match="Favorite">
  <xsl:param name="ChannelType" select="'TV'"/>
  
  <xsl:variable name="FavoriteId" select="Id"/>

    <xsl:variable name="channelNodes">
      <xsl:for-each select ="../../Satellites/Satellite/Transponders/Transponder/Channels/Channel[Name!='' and ChannelType=$ChannelType]/Favorites[Id=$FavoriteId]/..">
        <xsl:sort select="ChannelNo" data-type="number"/>
        <Channel>
          <ChannelNo><xsl:value-of select="position()"/></ChannelNo>
          <Name><xsl:value-of select="Name"/></Name>
        </Channel>
      </xsl:for-each>
    </xsl:variable>

    <xsl:call-template name="showChannels">
      <xsl:with-param name="title">
        <xsl:value-of select="Name"/>
          <xsl:choose>
            <xsl:when test="$ChannelType = 'TV'"> - TV</xsl:when>
            <xsl:otherwise> - Radio</xsl:otherwise>
          </xsl:choose>
        </xsl:with-param>
      <xsl:with-param name="channelNodes" select="msxsl:node-set($channelNodes)"/>
    </xsl:call-template>
  </xsl:template>

  <!-- ========================= -->
  <!-- Channel Template: item    -->
  <!-- ========================= -->
  <xsl:template match="Channel">
    <xsl:if test="(position() mod $rowsPerPage) = 1">
      <xsl:text disable-output-escaping = "yes">&lt;td valign='top' width='</xsl:text><xsl:value-of select="100 div $columnCount"/><xsl:text disable-output-escaping = "yes">%'&gt;&lt;table width='100%' border='0' cellPadding='1'&gt;</xsl:text>
    </xsl:if>
    <tr>
      <td align='right' width='5'>
        <xsl:choose>
          <xsl:when test="ECMPID = 0">
            <xsl:attribute name="bgColor"><xsl:value-of select="$channelFreeBgColor" /></xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="bgColor"><xsl:value-of select="$channelScramblBgColor" /></xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>

        <font>
          <xsl:attribute name="size"><xsl:value-of select="$fontSize" /></xsl:attribute>
          <xsl:value-of select="ChannelNo" />
        </font>
      </td>
      <td>
        <xsl:choose>
          <xsl:when test="ECMPID = 0">
            <xsl:attribute name="bgColor"><xsl:value-of select="$channelFreeBgColor" /></xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="bgColor"><xsl:value-of select="$channelScramblBgColor" /></xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>

        <font>
          <xsl:attribute name="size"><xsl:value-of select="$fontSize" /></xsl:attribute>
          <xsl:call-template name="showField">
            <xsl:with-param name="field" select="Name"/>
          </xsl:call-template>
        </font>
      </td>
    </tr>
    <xsl:if test="(position() mod $rowsPerPage) = 0">
      <xsl:text disable-output-escaping = "yes">&lt;/table&gt;&lt;/td&gt;</xsl:text>
    </xsl:if>
  </xsl:template>

  <!-- ========================= -->
  <!-- TEMPLATE: showChannels -->
  <!-- ========================= -->
  <xsl:template name="showChannels">
    <xsl:param name="title"/>
    <xsl:param name="channelNodes"/>

    <table width='100%' border='1' borderColor='black' cellSpacing='0'>
      <tr bgColor='#ffffb0'>
        <td colSpan='100' align='center'><font  color='#0000ff'>
        <B><xsl:value-of select="$title"/></B>
        (<xsl:value-of select="count(msxsl:node-set($channelNodes)/Channel)"/>)
        </font></td>
      </tr>
    </table>

    <table width='100%' border='0' borderColor='black' cellSpacing='0' cellPadding='2'>
      <xsl:for-each select ="msxsl:node-set($channelNodes)/Channel[(position() mod ($rowsPerPage * $columnCount)) = 1]" >
        <xsl:sort select="ChannelNo" data-type="number"/>

        <tr>
          <xsl:apply-templates select =". | following-sibling::Channel[position() &lt; ($columnCount * $rowsPerPage)]">
            <xsl:sort select="ChannelNo" data-type="number"/>
          </xsl:apply-templates>
        </tr>
        <tr><td colSpan='100'>&#160;</td></tr>
      </xsl:for-each>

      <xsl:if test="(count(msxsl:node-set($channelNodes)/Channel) mod $rowsPerPage) != 0">
        <xsl:text disable-output-escaping = "yes">&lt;/table&gt;&lt;/td&gt;</xsl:text>
      </xsl:if>
    </table>

  </xsl:template>

  <!-- ========================= -->
  <!-- TEMPLATE: showField -->
  <!-- ========================= -->
  <xsl:template name="showField">
    <xsl:param name="field"/>

    <xsl:choose>
      <xsl:when test="string-length(substring-before($field, '_TRSP#@')) > 0">
        <xsl:value-of select="substring-before($field, '_TRSP#@')"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:value-of select="$field"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

</xsl:stylesheet>
